Context class

Constructors

Context({String yamlKeyName = "change_app_name", String androidManifestPath = "android/app/src/main/AndroidManifest.xml", String pubspecPath = "pubspec.yaml", String iosInfoPlistPath = "ios/Runner/Info.plist", String ohosPath = "ohos/", String windowsCmakePath = "windows/CMakeLists.txt", String windowsRunnerRcPath = "windows/runner/Runner.rc", String windowsMainCppPath = "windows/runner/main.cpp", String linuxCmakePath = "linux/CMakeLists.txt", String linuxMyApplicationPath = "linux/runner/my_application.cc", String macosAppInfoPath = "macos/Runner/Configs/AppInfo.xcconfig", String webManifestPath = "web/manifest.json", String webIndexPath = "web/index.html"})

Properties

androidManifestPath String
final
hashCode int
The hash code for this object.
no setterinherited
iosInfoPlistPath String
final
linuxCmakePath String
final
linuxMyApplicationPath String
final
macosAppInfoPath String
final
ohosPath String
final
pubspecPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webIndexPath String
final
webManifestPath String
final
windowsCmakePath String
final
windowsMainCppPath String
final
windowsRunnerRcPath String
final
yamlKeyName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited