RenameCommand class abstract

Implementers

Constructors

RenameCommand(Context context)

Properties

context Context
final
dir String
no setter
dirPath String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasAllFiles(List<String> filePaths, String targetDescription) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateLauncherName() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited